<?php
/*
 * ------------------------------------------------------------------------
 * @version     5.3
 * @copyright   Copyright (C) 2021. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * Author:      Glenn Arkell
 * Website:     https://www.glennarkell.com.au
 * ------------------------------------------------------------------------
*/

defined('_JEXEC') or die();

define('MODIFIED', 1);
define('NOT_MODIFIED', 2);

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;
use \Joomla\Filesystem\File;
use \Joomla\Filesystem\Folder;
use \Joomla\Filesystem\Path;
use \Joomla\CMS\Installer\Installer;
use \Joomla\CMS\Installer\InstallerScript;
use \Joomla\CMS\Filter\OutputFilter;

/**
 * Updates the structure of the component
 */
class mod_gavotingInstallerScript extends InstallerScript
{
	/**
	 * Method called before install/update the component. Note: This method won't be called during uninstall process.
	 * @param   string $type   Type of process [install | update]
	 * @param   mixed  $parent Object who called this method
	 * @return boolean True if the process should continue, false otherwise
     * @throws Exception
	 */
	public function preflight($type, $parent)
	{
		// $parent is the class calling this method
		echo '<p>' . Text::_('MOD_GAVOTING_PREFLIGHT_TEXT') . '</p>';

        $path = Path::clean( JPATH_SITE . '/modules/mod_gavoting/' );
        $this->deleteFiles($path, 'helper', '.php');
        $this->deleteFiles($path, 'mod_gavoting', '.php');

        $mpath = Path::clean( JPATH_SITE . '/media/mod_gavoting/' );
        $this->deleteFiles($mpath, 'css/style', '.css');
        $this->deleteFolder($mpath.'js');
	}

	/**
	 * *********************  Data and Files stuff  *******************************
	 */
	/**
	/**
	 * Delete unwanted file
	 */
	public function deleteFiles($path = null, $file = null, $ext = null)
	{
        $path_to_file = $path . $file . $ext;
		if (is_file($path_to_file)) {
			File::delete($path_to_file);
			Factory::getApplication()->enqueueMessage('Deleted File - '.$path_to_file);
		}
	}

	/**
	 * Delete unwanted folder
	 */
	public function deleteFolder($path = null)
	{
		if (is_dir($path)) {
			Folder::delete($path);
			Factory::getApplication()->enqueueMessage('Deleted Folder - '.$path);
		}
	}

}
