<?php

/**
 * @version     5.3
 * @package     mod_gavoting
 * @author      Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright   2022 Glenn Arkell
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace GlennArkell\Module\Gavoting\Site\Helper;

defined('_JEXEC') or die;

use \Joomla\CMS\Factory;
use \Joomla\Filesystem\Path;
use \Joomla\Filesystem\File;
use \Joomla\Filesystem\Folder;
use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Component\ComponentHelper;
use \Joomla\CMS\Application\SiteApplication;
use \Joomla\Database\DatabaseAwareInterface;
use \Joomla\Database\DatabaseAwareTrait;
use \Joomla\Registry\Registry;
use \GlennArkell\Component\Gavoting\Administrator\Helper\GavotingHelper AS ComGavotingHelper;

/**
 * Helper for mod_gavoting
 */
class GavotingHelper implements DatabaseAwareInterface
{
    use DatabaseAwareTrait;

	/**
	 * Retrieve component items
	 * @param   Joomla\Registry\Registry &$params module parameters
	 * @return array Array with all the elements
     * @throws Exception
	 */
	public static function getLastElection( Registry $params, SiteApplication $app )
	{
		$catId = $params->get('election_year', 0);
		$exec_limit = $params->get('exec_limit', 0);
		$positions = $params->get('positions', 0);

        $db		= Factory::getContainer()->get('DatabaseDriver');
		$query = $db->getQuery(true);
		$query->select('a.*, c.title AS election_year ');
		$query->from('#__gavoting_positions AS a');
		$query->join('LEFT', '#__categories AS c ON c.id = a.cat_id');
    	$query->where('a.state = 2 ');
		if ($catId) {
            $query->where('a.cat_id = ' . (int) $catId);
        } else {
            $query->order('a.cat_id DESC ');
        }

		$db->setQuery($query);
		$elections = $db->loadObjectList();

		if ($exec_limit) {
            $posName = array();
            foreach ($positions as $pos) {
                $posName[] = ComGavotingHelper::getPosition($pos)->pos_name;
            }
            foreach ($elections as $e) {
                if (in_array($e->pos_name, $posName)) {
                    $items[] = $e;
                }
            }
        } else {
            $items = $elections;
        }

		return $items;
	}

    /**
     * Gets a category name from id reference
     */
    public static function getCategoryName($id) {

        // get the club names from the database
        $db		= Factory::getContainer()->get('DatabaseDriver');
		$query	= $db->getQuery(true);
        $query->clear();
		$query->select(' title ');
		$query->from(' #__categories ');
		$query->where(' id = '.(int) $id );
		$db->setQuery((string)$query);

	    try {
	        return $db->loadResult();
	    } catch (\RuntimeException $e) {
	        Factory::getApplication()->enqueueMessage($e->getMessage(), 'danger');
	        return false;
	    }
    }

	/**
	 * Get the record
	 * @params integer Record id reference
	 * @return object list of records
	 */
	public static function getPosition($position)
	{
		// get the broadcast types from the database
        $db		= Factory::getContainer()->get('DatabaseDriver');
		$query	= $db->getQuery(true);
        $query->clear();
		$query->select(' a.*, cat.title as election_year, CONCAT(cat.title," - ",a.pos_name) as position_name ');
		$query->from(' #__gavoting_positions AS a ');
		$query->join('LEFT',' #__categories AS cat ON cat.id = a.cat_id');
		$query->where('a.id = '.(int) $position);
		$db->setQuery((string)$query);
	    try {
	        return $db->loadObject();
	    } catch (\RuntimeException $e) {
	        Factory::getApplication()->enqueueMessage($e->getMessage(), 'danger');
	        return false;
	    }

	}

	public static function getListOptions($table = '#__gavoting_positions', $label = 'Position', $field = 'name' )
	{
        $params = ComponentHelper::getParams('com_gavoting');
        $sel_label = strtoupper('MOD_GAVOTING_SELECT_'.$label);
        $sel_label = Text::_($sel_label);
        $db		= Factory::getContainer()->get('DatabaseDriver');
		$query	= $db->getQuery(true);
        $query->clear();
		$query->select(' "0" as "value", " - '.$sel_label.' - " as "text" UNION SELECT a.id as value, a.'.$field.' as text ');
		$query->from( $db->quoteName($table) . ' AS a ' );
		$query->where(' a.state = 1' );
		if ($table == '#__content') {
            $query->where(' a.catid = '.(int) $params->get('jd_cat', 0) );
        }
		$query->order(' text ASC ' );
		$db->setQuery((string)$query);

	    try {
	        $options = $db->loadObjectList();
	    } catch (\RuntimeException $e) {
	        Factory::getApplication()->enqueueMessage($e->getMessage(),'danger');
	        return false;
	    }

		return $options;
	}

}
